Store

Struct Store 

pub struct Store { /* private fields */ }
FastEdge key-value persistent store resource

Implementations

Source

impl Store

pub fn open(name: &str) -> Result<Store, Error>

Open the store with the specified name.

error::no-such-store will be raised if the name is not recognized.

Source

impl Store

pub fn get(&self, key: &str) -> Result<Option<Value>, Error>

Get the value associated with the specified key

Returns ok(none) if the key does not exist.

Source

impl Store

pub fn scan(&self, pattern: &str) -> Result<Vec<String>, Error>

Interface to scan over keys in the store. It matches glob-style pattern filter on each element from the retrieved collection.

Returns an array of elements as a list of keys.

Source

impl Store

pub fn zrange_by_score( &self, key: &str, min: f64, max: f64, ) -> Result<Vec<(Value, f64)>, Error>

Get all the elements with score from the sorted set at key with a f64 score between min and max (including elements with score equal to min or max). The elements are considered to be ordered from low to high scores.

Returns empty Vec if the key does not exist or if no elements have scores between min and max.

Source

impl Store

pub fn zscan( &self, key: &str, pattern: &str, ) -> Result<Vec<(Value, f64)>, Error>

Interface to scan through a sorted set by key It matches glob-style pattern filter on each elements from the retrieved collection.

Returns an array of elements as a list of value of the Sorted Set.

Source

impl Store

pub fn bf_exists(&self, key: &str, item: &str) -> Result<bool, Error>

Determines whether a given item was added to a Bloom filter.

Returns one of these replies: ‘true’ means that, with high probability, item was already added to the filter, and ‘false’ means that key does not exist or that item had not been added to the filter.