pub struct Store { /* private fields */ }Expand description
FastEdge key-value persistent store resource
Implementations
Sourceimpl Store
impl Store
Sourcepub fn zrange_by_score(
&self,
key: &str,
min: f64,
max: f64,
) -> Result<Vec<(Value, f64)>, Error>
pub fn zrange_by_score( &self, key: &str, min: f64, max: f64, ) -> Result<Vec<(Value, f64)>, Error>
Get all the elements with score from the sorted set at key with a f64 score between min and max
(including elements with score equal to min or max). The elements are considered to be ordered from low to high
scores.
Returns empty Vec if the key does not exist or if no elements have scores between min and max.
Sourceimpl Store
impl Store
Sourcepub fn bf_exists(&self, key: &str, item: &str) -> Result<bool, Error>
pub fn bf_exists(&self, key: &str, item: &str) -> Result<bool, Error>
Determines whether a given item was added to a Bloom filter.
Returns one of these replies: ‘true’ means that, with high probability, item was already added to the filter, and ‘false’ means that key does not exist or that item had not been added to the filter.